@@ -11,10 +11,6 @@
 
 namespace fz {
 
-file::file()
-{
-}
-
 file::file(native_string const& f, mode m, creation_flags d)
 {
 	open(f, m, d);
@@ -133,6 +129,11 @@ bool remove_file(fz::native_string const& name)
 	return DeleteFileW(name.c_str()) != 0;
 }
 
+bool file::fsync()
+{
+	return FlushFileBuffers(hFile_) != 0;
+}
+
 #else
 
 bool file::open(native_string const& f, mode m, creation_flags d)
@@ -244,6 +245,15 @@ bool remove_file(fz::native_string const& name)
 	return unlink(name.c_str()) == 0;
 }
 
+bool file::fsync()
+{
+#if defined(_POSIX_SYNCHRONIZED_IO) && _POSIX_SYNCHRONIZED_IO > 0
+	return fdatasync(fd_) == 0;
+#else
+	return ::fsync(fd_) == 0;
+#endif
+}
+
 #endif
 
 }
